@@ -30,6 +30,7 @@ type Config struct {
 	Commands       *[]Command             `yaml:"commands"        json:"commands"`
 	Languages      *map[string][]Language `yaml:"languages"       json:"languages"`
 	RootMarkers    *[]string              `yaml:"root-markers"    json:"rootMarkers"`
+	TriggerChars   []string              `yaml:"trigger-chars"   json:"triggerChars"`
 	LintDebounce   Duration               `yaml:"lint-debounce"   json:"lintDebounce"`
 	FormatDebounce Duration               `yaml:"format-debounce" json:"formatDebounce"`
 
@@ -71,6 +72,7 @@ type Language struct {
 	HoverCommand       string            `yaml:"hover-command" json:"hoverCommand"`
 	HoverStdin         bool              `yaml:"hover-stdin" json:"hoverStdin"`
 	HoverType          string            `yaml:"hover-type" json:"hoverType"`
+	HoverChars         string            `yaml:"hover-chars" json:"hoverChars"`
 	Env                []string          `yaml:"env" json:"env"`
 	RootMarkers        []string          `yaml:"root-markers" json:"rootMarkers"`
 	RequireMarker      bool              `yaml:"require-marker" json:"requireMarker"`
@@ -99,6 +101,7 @@ func NewHandler(config *Config) jsonrpc2.Handler {
 		conn:           nil,
 		filename:       config.Filename,
 		rootMarkers:    *config.RootMarkers,
+		triggerChars:   config.TriggerChars,
 
 		lastPublishedURIs: make(map[string]map[DocumentURI]struct{}),
 	}
@@ -123,6 +126,7 @@ type langHandler struct {
 	filename          string
 	folders           []string
 	rootMarkers       []string
+	triggerChars      []string
 
 	// lastPublishedURIs is mapping from LanguageID string to mapping of
 	// whether diagnostics are published in a DocumentURI or not.
@@ -434,7 +438,7 @@ func (h *langHandler) lint(ctx context.Context, uri DocumentURI) (map[DocumentUR
 			h.logMessage(LogError, "command `"+command+"` exit with zero. probably you forgot to specify `lint-ignore-exit-code: true`.")
 			continue
 		}
-		if h.loglevel >= 1 {
+		if h.loglevel >= 3 {
 			h.logger.Println(command+":", string(b))
 		}
 		var source *string
@@ -477,6 +481,10 @@ func (h *langHandler) lint(ctx context.Context, uri DocumentURI) (map[DocumentUR
 				entry.Col = entry.Col + config.LintOffsetColumns
 			}
 
+			if entry.Lnum == 0 {
+				entry.Lnum = 1 // entry.Lnum == 0 indicates the top line, set to 1 because it is subtracted later
+			}
+
 			if entry.Col == 0 {
 				entry.Col = 1 // entry.Col == 0 indicates the whole line without column, set to 1 because it is subtracted later
 			} else {
@@ -505,7 +513,6 @@ func (h *langHandler) lint(ctx context.Context, uri DocumentURI) (map[DocumentUR
 			}
 
 			diagURI := uri
-			h.logger.Println(entry.Filename)
 			if entry.Filename != "" {
 				if filepath.IsAbs(entry.Filename) {
 					diagURI = toURI(entry.Filename)
